pub struct GraphAffectedArgs {
pub table: String,
pub schema_path: String,
}Fields
table: Stringschema_path: StringTrait Implementations
Sourceimpl Debug for GraphAffectedArgs
impl Debug for GraphAffectedArgs
Sourceimpl<'de> Deserialize<'de> for GraphAffectedArgs
impl<'de> Deserialize<'de> for GraphAffectedArgs
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for GraphAffectedArgs
impl JsonSchema for GraphAffectedArgs
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for GraphAffectedArgs
impl RefUnwindSafe for GraphAffectedArgs
impl Send for GraphAffectedArgs
impl Sync for GraphAffectedArgs
impl Unpin for GraphAffectedArgs
impl UnsafeUnpin for GraphAffectedArgs
impl UnwindSafe for GraphAffectedArgs