pub struct GraphTraverseArgs {
pub table: String,
pub schema_path: String,
pub depth: Option<u32>,
pub direction: Option<String>,
}Fields
table: Stringschema_path: Stringdepth: Option<u32>direction: Option<String>Trait Implementations
Sourceimpl Debug for GraphTraverseArgs
impl Debug for GraphTraverseArgs
Sourceimpl<'de> Deserialize<'de> for GraphTraverseArgs
impl<'de> Deserialize<'de> for GraphTraverseArgs
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for GraphTraverseArgs
impl JsonSchema for GraphTraverseArgs
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for GraphTraverseArgs
impl RefUnwindSafe for GraphTraverseArgs
impl Send for GraphTraverseArgs
impl Sync for GraphTraverseArgs
impl Unpin for GraphTraverseArgs
impl UnsafeUnpin for GraphTraverseArgs
impl UnwindSafe for GraphTraverseArgs