pub struct LoadFileArgs {
pub path: String,
}Fields
path: StringTrait Implementations
Sourceimpl Debug for LoadFileArgs
impl Debug for LoadFileArgs
Sourceimpl<'de> Deserialize<'de> for LoadFileArgs
impl<'de> Deserialize<'de> for LoadFileArgs
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for LoadFileArgs
impl JsonSchema for LoadFileArgs
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for LoadFileArgs
impl RefUnwindSafe for LoadFileArgs
impl Send for LoadFileArgs
impl Sync for LoadFileArgs
impl Unpin for LoadFileArgs
impl UnsafeUnpin for LoadFileArgs
impl UnwindSafe for LoadFileArgs