pub struct LoadProjectArgs {
pub path: String,
pub clean: Option<bool>,
}Fields
path: Stringclean: Option<bool>Trait Implementations
Sourceimpl Debug for LoadProjectArgs
impl Debug for LoadProjectArgs
Sourceimpl<'de> Deserialize<'de> for LoadProjectArgs
impl<'de> Deserialize<'de> for LoadProjectArgs
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for LoadProjectArgs
impl JsonSchema for LoadProjectArgs
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for LoadProjectArgs
impl RefUnwindSafe for LoadProjectArgs
impl Send for LoadProjectArgs
impl Sync for LoadProjectArgs
impl Unpin for LoadProjectArgs
impl UnsafeUnpin for LoadProjectArgs
impl UnwindSafe for LoadProjectArgs